require 'uu/os/rest/dto'
require 'uu/os/uesuri'



module UU
  module ADK
    module App
      # App Create DTO.
      # @deprecated Use {UU::OS::AppMetaModel::AppMetaModelCreate} instead.
      class AppCreate < UU::OS::REST::DTO

        # UESURI of the meta artifact. Only a meta artifact with the template class of Organizational
        # Unit (not its descendants) can be used. If the rights does not permit to create a
        # new organizational unit from the meta artifact in the specified location, the
        # create command fails.
        attr_accessor :meta_artifact_uri

        # Code of the new organizational unit. When null is set, the code is generated automatically
        # using the system sequence. The code must be unique in the given territory, otherwise
        # the create command fails.
        attr_accessor :code
        
        # UESURI of appbox from which was the app created.
        attr_accessor :app_box_uri

        # Name of the new organizational unit. When null is set, tName from meta artifact
        # is used if set, otherwise the create command fails.
        attr_accessor :name

        # Description of the new organizational unit. When null is set, tDescription from
        # meta artifact is used if set, otherwise no description is set on the new organizational
        # unit.
        attr_accessor :description

        # UESURI of the competent role. When null is set, the executive role from authorization
        # is used. If no role is authorized to create the new organizational unit into specified
        # container, the create command fails. If the selected role doesn't have connected
        # the role interface with the selected meta artifact, the create command fails.
        # If the selected role doesn't belong to one of superior organizational units, the
        # create command fails.
        attr_accessor :competent_role_uri

        # Security level. When null is set, security level is taken from the meta artifact
        # tSecurityLevel. If the meta artifact tSecurityLevel is higher than theuser's
        # security clearance, the create command fails.
        attr_accessor :security_level

        # URI of the organizational unit's icon. When nil is set, the organizational unit
        # uses icon from meta artifact.
        #
        # @example Allowed format of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{CODE_OF_ICON}
        #
        # @example An example of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{ART_077}
        attr_accessor :icon_uri

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end
        
        def app_box_uri
          attributes[:appBoxUri]
        end

        def app_box_uri=(val)
          if val
            attributes[:appBoxUri] = UU::OS::UESURI.new(val)
          else
            attributes[:appBoxUri] = nil
          end
        end

      end
    end

  end
end
